@@ -3,7 +3,7 @@ from classytags.core import Tag, Options
 from classytags.parser import Parser
 from django import template
 from django.conf import settings
-from sekizai.settings import VARNAME
+from django.utils.importlib import import_module
 
 register = template.Library()
 
@@ -19,7 +19,7 @@ def validate_context(context):
     Raises a TemplateSyntaxError if the context is invalid and we're in debug
     mode.
     """
-    if VARNAME in context:
+    if getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER') in context:
         return True
     if not settings.TEMPLATE_DEBUG:
         return False
@@ -29,6 +29,13 @@ def validate_context(context):
         "render your templates."
     )
 
+def import_processor(import_path):
+    if '.' not in import_path:
+        raise TypeError("Import paths must contain at least one '.'")
+    module_name, object_name = import_path.rsplit('.', 1)
+    module = import_module(module_name)
+    return getattr(module, object_name)
+
 
 class SekizaiParser(Parser):
     def parse_blocks(self):
@@ -57,14 +64,20 @@ class RenderBlock(Tag):
     
     options = Options(
         Argument('name'),
+        'postprocessor',
+        Argument('postprocessor', required=False, default=None, resolve=False),
         parser_class=SekizaiParser,
     )
         
-    def render_tag(self, context, name, nodelist):
+    def render_tag(self, context, name, postprocessor, nodelist):
         if not validate_context(context):
             return nodelist.render(context)
         rendered_contents = nodelist.render(context)
-        data = context[VARNAME][name].render()
+        varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
+        data = context[varname][name].render()
+        if postprocessor:
+            func = import_processor(postprocessor)
+            data = func(data, name)
         return '%s\n%s' % (data, rendered_contents)
 register.tag(RenderBlock)
 
@@ -78,7 +91,8 @@ class AddData(SekizaiTag):
     )
     
     def render_tag(self, context, key, value):
-        context[VARNAME][key].append(value)
+        varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
+        context[varname][key].append(value)
         return ''
 register.tag(AddData)
 
@@ -89,18 +103,19 @@ class WithData(SekizaiTag):
     options = Options(
         Argument('name'),
         'as', 
-        Argument('varname', resolve=False),
+        Argument('variable', resolve=False),
         blocks=[
             ('end_with_data', 'inner_nodelist'),
         ],
         parser_class=SekizaiParser,
     )
     
-    def render_tag(self, context, name, varname, inner_nodelist, nodelist):
+    def render_tag(self, context, name, variable, inner_nodelist, nodelist):
         rendered_contents = nodelist.render(context)
-        data = context[VARNAME][name]
+        varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
+        data = context[varname][name]
         context.push()
-        context[varname] = data
+        context[variable] = data
         inner_contents = inner_nodelist.render(context)
         context.pop()
         return '%s\n%s' % (inner_contents, rendered_contents)
@@ -117,6 +132,7 @@ class Addtoblock(SekizaiTag):
     
     def render_tag(self, context, name, nodelist):
         rendered_contents = nodelist.render(context)
-        context[VARNAME][name].append(rendered_contents)
+        varname = getattr(settings, 'SEKIZAI_VARNAME', 'SEKIZAI_CONTENT_HOLDER')
+        context[varname][name].append(rendered_contents)
         return ""
 register.tag(Addtoblock)
